# Welcome to maxrf4u


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Macro X-Ray Fluorescence (MA-XRF) scanning of cultural heritage objects
is becoming a standard technique that is increasingly applied also to
paper based artworks. Unfortunately, the visualization and
interpretation of MA-XRF data is technically challenging and therefore
obstructing interdisciplinary cooperation. That is why I have started to
develop the open source python package `maxrf4u` to help you and me with
our data analysis.

This package is developed out in the open. If you are interested you can
follow my ideas under construction in this documentation and already try
out the Jupyter
[notebooks](https://github.com/fligt/maxrf4u/tree/main/notebooks) in
this repository. Although this is **a-work-in-progress**, the package
available for installation from the python package index:

[![](https://badge.fury.io/py/maxrf4u.svg)](https://pypi.org/project/maxrf4u/)

Frank Ligterink

See [link](https://fligt.github.io/maxrf4u/) to documentation.
